"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServiceProfile = void 0;
const IoK8sApimachineryPkgApisMetaV1ObjectMeta_1 = require("@kubernetes-models/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta");
const base_1 = require("@kubernetes-models/base");
const validate_1 = require("@kubernetes-models/validate");
const schemaId = "linkerd.io.v1alpha1.ServiceProfile";
const schema = {
    "type": "object",
    "properties": {
        "spec": {
            "type": "object",
            "required": [
                "routes"
            ],
            "properties": {
                "dstOverrides": {
                    "type": "array",
                    "required": [
                        "authority",
                        "weight"
                    ],
                    "items": {
                        "type": "object",
                        "properties": {
                            "authority": {
                                "type": "string",
                                "nullable": true
                            },
                            "weight": {
                                "oneOf": [
                                    {
                                        "anyOf": [
                                            {
                                                "type": "integer"
                                            },
                                            {
                                                "type": "string"
                                            }
                                        ],
                                        "pattern": "^(\\+|-)?(([0-9]+(\\.[0-9]*)?)|(\\.[0-9]+))(([KMGTPE]i)|[numkMGTPE]|([eE](\\+|-)?(([0-9]+(\\.[0-9]*)?)|(\\.[0-9]+))))?$"
                                    },
                                    {
                                        "type": "null"
                                    }
                                ]
                            }
                        }
                    },
                    "nullable": true
                },
                "opaquePorts": {
                    "type": "array",
                    "items": {
                        "type": "string"
                    },
                    "nullable": true
                },
                "retryBudget": {
                    "type": "object",
                    "required": [
                        "minRetriesPerSecond",
                        "retryRatio",
                        "ttl"
                    ],
                    "properties": {
                        "minRetriesPerSecond": {
                            "format": "int32",
                            "type": "integer"
                        },
                        "retryRatio": {
                            "type": "number",
                            "format": "float"
                        },
                        "ttl": {
                            "type": "string"
                        }
                    },
                    "nullable": true
                },
                "routes": {
                    "type": "array",
                    "items": {
                        "type": "object",
                        "required": [
                            "condition",
                            "name"
                        ],
                        "properties": {
                            "condition": {
                                "type": "object",
                                "properties": {
                                    "pathRegex": {
                                        "type": "string",
                                        "nullable": true
                                    },
                                    "method": {
                                        "type": "string",
                                        "nullable": true
                                    },
                                    "all": {
                                        "type": "array",
                                        "items": {
                                            "type": "object",
                                            "properties": {}
                                        },
                                        "nullable": true
                                    },
                                    "any": {
                                        "type": "array",
                                        "items": {
                                            "type": "object",
                                            "properties": {}
                                        },
                                        "nullable": true
                                    },
                                    "not": {
                                        "type": "array",
                                        "items": {
                                            "type": "object",
                                            "properties": {}
                                        },
                                        "nullable": true
                                    }
                                }
                            },
                            "isRetryable": {
                                "type": "boolean",
                                "nullable": true
                            },
                            "name": {
                                "type": "string"
                            },
                            "timeout": {
                                "type": "string",
                                "nullable": true
                            },
                            "responseClasses": {
                                "type": "array",
                                "items": {
                                    "type": "object",
                                    "required": [
                                        "condition"
                                    ],
                                    "properties": {
                                        "condition": {
                                            "type": "object",
                                            "properties": {
                                                "all": {
                                                    "type": "array",
                                                    "items": {
                                                        "type": "object",
                                                        "properties": {}
                                                    },
                                                    "nullable": true
                                                },
                                                "any": {
                                                    "type": "array",
                                                    "items": {
                                                        "type": "object",
                                                        "properties": {}
                                                    },
                                                    "nullable": true
                                                },
                                                "not": {
                                                    "type": "array",
                                                    "items": {
                                                        "type": "object",
                                                        "properties": {}
                                                    },
                                                    "nullable": true
                                                },
                                                "status": {
                                                    "type": "object",
                                                    "properties": {
                                                        "max": {
                                                            "format": "int32",
                                                            "type": "integer",
                                                            "nullable": true
                                                        },
                                                        "min": {
                                                            "format": "int32",
                                                            "type": "integer",
                                                            "nullable": true
                                                        }
                                                    },
                                                    "nullable": true
                                                }
                                            }
                                        },
                                        "isFailure": {
                                            "type": "boolean",
                                            "nullable": true
                                        }
                                    }
                                },
                                "nullable": true
                            }
                        }
                    }
                }
            },
            "nullable": true
        },
        "apiVersion": {
            "type": "string",
            "enum": [
                "linkerd.io/v1alpha1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "ServiceProfile"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        }
    },
    "required": [
        "apiVersion",
        "kind"
    ]
};
class ServiceProfile extends base_1.Model {
    constructor(data) {
        super({
            apiVersion: ServiceProfile.apiVersion,
            kind: ServiceProfile.kind,
            ...data
        });
    }
}
exports.ServiceProfile = ServiceProfile;
ServiceProfile.apiVersion = "linkerd.io/v1alpha1";
ServiceProfile.kind = "ServiceProfile";
ServiceProfile.is = (0, base_1.createTypeMetaGuard)(ServiceProfile);
(0, base_1.setSchema)(ServiceProfile, schemaId, () => {
    (0, IoK8sApimachineryPkgApisMetaV1ObjectMeta_1.addSchema)();
    (0, validate_1.register)(schemaId, schema);
});
