import { addSchema } from "@kubernetes-models/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@kubernetes-models/base";
import { register } from "@kubernetes-models/validate";
const schemaId = "multicluster.linkerd.io.v1alpha1.Link";
const schema = {
    "type": "object",
    "properties": {
        "spec": {
            "type": "object",
            "properties": {
                "clusterCredentialsSecret": {
                    "type": "string",
                    "nullable": true
                },
                "gatewayAddress": {
                    "type": "string",
                    "nullable": true
                },
                "gatewayIdentity": {
                    "type": "string",
                    "nullable": true
                },
                "gatewayPort": {
                    "type": "string",
                    "nullable": true
                },
                "probeSpec": {
                    "type": "object",
                    "properties": {
                        "path": {
                            "type": "string",
                            "nullable": true
                        },
                        "period": {
                            "type": "string",
                            "nullable": true
                        },
                        "port": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "nullable": true
                },
                "selector": {
                    "type": "object",
                    "properties": {
                        "matchLabels": {
                            "type": "object",
                            "properties": {},
                            "nullable": true
                        },
                        "matchExpressions": {
                            "type": "array",
                            "items": {
                                "type": "object",
                                "required": [
                                    "key",
                                    "operator"
                                ],
                                "properties": {
                                    "key": {
                                        "type": "string"
                                    },
                                    "operator": {
                                        "type": "string",
                                        "enum": [
                                            "In",
                                            "NotIn",
                                            "Exists",
                                            "DoesNotExist"
                                        ]
                                    },
                                    "values": {
                                        "type": "array",
                                        "items": {
                                            "type": "string"
                                        },
                                        "nullable": true
                                    }
                                }
                            },
                            "nullable": true
                        }
                    },
                    "nullable": true
                },
                "remoteDiscoverySelector": {
                    "type": "object",
                    "properties": {
                        "matchLabels": {
                            "type": "object",
                            "properties": {},
                            "nullable": true
                        },
                        "matchExpressions": {
                            "type": "array",
                            "items": {
                                "type": "object",
                                "required": [
                                    "key",
                                    "operator"
                                ],
                                "properties": {
                                    "key": {
                                        "type": "string"
                                    },
                                    "operator": {
                                        "type": "string",
                                        "enum": [
                                            "In",
                                            "NotIn",
                                            "Exists",
                                            "DoesNotExist"
                                        ]
                                    },
                                    "values": {
                                        "type": "array",
                                        "items": {
                                            "type": "string"
                                        },
                                        "nullable": true
                                    }
                                }
                            },
                            "nullable": true
                        }
                    },
                    "nullable": true
                },
                "targetClusterName": {
                    "type": "string",
                    "nullable": true
                },
                "targetClusterDomain": {
                    "type": "string",
                    "nullable": true
                },
                "targetClusterLinkerdNamespace": {
                    "type": "string",
                    "nullable": true
                }
            },
            "nullable": true
        },
        "apiVersion": {
            "type": "string",
            "enum": [
                "multicluster.linkerd.io/v1alpha1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "Link"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        }
    },
    "required": [
        "apiVersion",
        "kind"
    ]
};
export class Link extends Model {
    constructor(data) {
        super({
            apiVersion: Link.apiVersion,
            kind: Link.kind,
            ...data
        });
    }
}
Link.apiVersion = "multicluster.linkerd.io/v1alpha1";
Link.kind = "Link";
Link.is = createTypeMetaGuard(Link);
setSchema(Link, schemaId, () => {
    addSchema();
    register(schemaId, schema);
});
