import { addSchema } from "@kubernetes-models/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@kubernetes-models/base";
import { register } from "@kubernetes-models/validate";
const schemaId = "policy.linkerd.io.v1alpha1.AuthorizationPolicy";
const schema = {
    "type": "object",
    "properties": {
        "spec": {
            "type": "object",
            "required": [
                "targetRef",
                "requiredAuthenticationRefs"
            ],
            "properties": {
                "targetRef": {
                    "type": "object",
                    "required": [
                        "kind",
                        "name"
                    ],
                    "properties": {
                        "group": {
                            "maxLength": 253,
                            "type": "string",
                            "pattern": "^$|^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$",
                            "nullable": true
                        },
                        "kind": {
                            "maxLength": 63,
                            "minLength": 1,
                            "type": "string",
                            "pattern": "^[a-zA-Z]([-a-zA-Z0-9]*[a-zA-Z0-9])?$"
                        },
                        "name": {
                            "maxLength": 253,
                            "minLength": 1,
                            "type": "string"
                        }
                    }
                },
                "requiredAuthenticationRefs": {
                    "type": "array",
                    "items": {
                        "type": "object",
                        "required": [
                            "kind",
                            "name"
                        ],
                        "properties": {
                            "group": {
                                "maxLength": 253,
                                "type": "string",
                                "pattern": "^$|^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$",
                                "nullable": true
                            },
                            "kind": {
                                "maxLength": 63,
                                "minLength": 1,
                                "type": "string",
                                "pattern": "^[a-zA-Z]([-a-zA-Z0-9]*[a-zA-Z0-9])?$"
                            },
                            "name": {
                                "maxLength": 253,
                                "minLength": 1,
                                "type": "string"
                            },
                            "namespace": {
                                "maxLength": 253,
                                "type": "string",
                                "nullable": true
                            }
                        }
                    }
                }
            }
        },
        "apiVersion": {
            "type": "string",
            "enum": [
                "policy.linkerd.io/v1alpha1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "AuthorizationPolicy"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        }
    },
    "required": [
        "spec",
        "apiVersion",
        "kind"
    ]
};
export class AuthorizationPolicy extends Model {
    constructor(data) {
        super({
            apiVersion: AuthorizationPolicy.apiVersion,
            kind: AuthorizationPolicy.kind,
            ...data
        });
    }
}
AuthorizationPolicy.apiVersion = "policy.linkerd.io/v1alpha1";
AuthorizationPolicy.kind = "AuthorizationPolicy";
AuthorizationPolicy.is = createTypeMetaGuard(AuthorizationPolicy);
setSchema(AuthorizationPolicy, schemaId, () => {
    addSchema();
    register(schemaId, schema);
});
