import { addSchema } from "@kubernetes-models/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@kubernetes-models/base";
import { register } from "@kubernetes-models/validate";
const schemaId = "policy.linkerd.io.v1alpha1.MeshTLSAuthentication";
const schema = {
    "type": "object",
    "properties": {
        "spec": {
            "type": "object",
            "oneOf": [
                {
                    "required": [
                        "identities"
                    ]
                },
                {
                    "required": [
                        "identityRefs"
                    ]
                }
            ],
            "properties": {
                "identities": {
                    "type": "array",
                    "minItems": 1,
                    "items": {
                        "type": "string",
                        "pattern": "^(\\*|[a-z0-9]([-a-z0-9]*[a-z0-9])?)(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$"
                    },
                    "nullable": true
                },
                "identityRefs": {
                    "type": "array",
                    "minItems": 1,
                    "items": {
                        "type": "object",
                        "required": [
                            "kind"
                        ],
                        "properties": {
                            "group": {
                                "maxLength": 253,
                                "type": "string",
                                "pattern": "^$|^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$",
                                "nullable": true
                            },
                            "kind": {
                                "maxLength": 63,
                                "minLength": 1,
                                "type": "string",
                                "pattern": "^[a-zA-Z]([-a-zA-Z0-9]*[a-zA-Z0-9])?$"
                            },
                            "name": {
                                "maxLength": 253,
                                "minLength": 1,
                                "type": "string",
                                "nullable": true
                            },
                            "namespace": {
                                "maxLength": 253,
                                "type": "string",
                                "nullable": true
                            }
                        }
                    },
                    "nullable": true
                }
            }
        },
        "apiVersion": {
            "type": "string",
            "enum": [
                "policy.linkerd.io/v1alpha1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "MeshTLSAuthentication"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        }
    },
    "required": [
        "spec",
        "apiVersion",
        "kind"
    ]
};
export class MeshTLSAuthentication extends Model {
    constructor(data) {
        super({
            apiVersion: MeshTLSAuthentication.apiVersion,
            kind: MeshTLSAuthentication.kind,
            ...data
        });
    }
}
MeshTLSAuthentication.apiVersion = "policy.linkerd.io/v1alpha1";
MeshTLSAuthentication.kind = "MeshTLSAuthentication";
MeshTLSAuthentication.is = createTypeMetaGuard(MeshTLSAuthentication);
setSchema(MeshTLSAuthentication, schemaId, () => {
    addSchema();
    register(schemaId, schema);
});
