import { addSchema } from "@kubernetes-models/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@kubernetes-models/base";
import { register } from "@kubernetes-models/validate";
const schemaId = "policy.linkerd.io.v1beta3.HTTPRoute";
const schema = {
    "type": "object",
    "properties": {
        "apiVersion": {
            "type": "string",
            "enum": [
                "policy.linkerd.io/v1beta3"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "HTTPRoute"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        },
        "spec": {
            "properties": {
                "hostnames": {
                    "items": {
                        "maxLength": 253,
                        "minLength": 1,
                        "type": "string",
                        "pattern": "^(\\*\\.)?[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$"
                    },
                    "maxItems": 16,
                    "type": "array",
                    "nullable": true
                },
                "parentRefs": {
                    "items": {
                        "properties": {
                            "group": {
                                "default": "policy.linkerd.io",
                                "maxLength": 253,
                                "type": "string",
                                "pattern": "^$|^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$",
                                "nullable": true
                            },
                            "kind": {
                                "default": "Gateway",
                                "maxLength": 63,
                                "minLength": 1,
                                "type": "string",
                                "pattern": "^[a-zA-Z]([-a-zA-Z0-9]*[a-zA-Z0-9])?$",
                                "nullable": true
                            },
                            "name": {
                                "maxLength": 253,
                                "minLength": 1,
                                "type": "string"
                            },
                            "namespace": {
                                "maxLength": 63,
                                "minLength": 1,
                                "type": "string",
                                "pattern": "^[a-z0-9]([-a-z0-9]*[a-z0-9])?$",
                                "nullable": true
                            },
                            "port": {
                                "format": "int32",
                                "type": "integer",
                                "minimum": 1,
                                "maximum": 65535,
                                "nullable": true
                            },
                            "sectionName": {
                                "maxLength": 253,
                                "minLength": 1,
                                "type": "string",
                                "pattern": "^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$",
                                "nullable": true
                            }
                        },
                        "required": [
                            "name"
                        ],
                        "type": "object"
                    },
                    "maxItems": 32,
                    "type": "array",
                    "nullable": true
                },
                "rules": {
                    "default": [
                        {
                            "matches": [
                                {
                                    "path": {
                                        "type": "PathPrefix",
                                        "value": "/"
                                    }
                                }
                            ]
                        }
                    ],
                    "items": {
                        "properties": {
                            "backendRefs": {
                                "items": {
                                    "properties": {
                                        "group": {
                                            "default": "",
                                            "maxLength": 253,
                                            "type": "string",
                                            "pattern": "^$|^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$",
                                            "nullable": true
                                        },
                                        "kind": {
                                            "default": "Service",
                                            "maxLength": 63,
                                            "minLength": 1,
                                            "type": "string",
                                            "pattern": "^[a-zA-Z]([-a-zA-Z0-9]*[a-zA-Z0-9])?$",
                                            "nullable": true
                                        },
                                        "name": {
                                            "maxLength": 253,
                                            "minLength": 1,
                                            "type": "string"
                                        },
                                        "namespace": {
                                            "maxLength": 63,
                                            "minLength": 1,
                                            "type": "string",
                                            "pattern": "^[a-z0-9]([-a-z0-9]*[a-z0-9])?$",
                                            "nullable": true
                                        },
                                        "port": {
                                            "format": "int32",
                                            "type": "integer",
                                            "minimum": 1,
                                            "maximum": 65535,
                                            "nullable": true
                                        },
                                        "weight": {
                                            "default": 1,
                                            "format": "int32",
                                            "type": "integer",
                                            "minimum": 0,
                                            "maximum": 1000000,
                                            "nullable": true
                                        },
                                        "filters": {
                                            "items": {
                                                "properties": {
                                                    "requestHeaderModifier": {
                                                        "properties": {
                                                            "add": {
                                                                "items": {
                                                                    "properties": {
                                                                        "name": {
                                                                            "maxLength": 256,
                                                                            "minLength": 1,
                                                                            "type": "string",
                                                                            "pattern": "^[A-Za-z0-9!#$%&'*+\\-.^_\\x60|~]+$"
                                                                        },
                                                                        "value": {
                                                                            "maxLength": 4096,
                                                                            "minLength": 1,
                                                                            "type": "string"
                                                                        }
                                                                    },
                                                                    "required": [
                                                                        "name",
                                                                        "value"
                                                                    ],
                                                                    "type": "object"
                                                                },
                                                                "maxItems": 16,
                                                                "type": "array",
                                                                "nullable": true
                                                            },
                                                            "remove": {
                                                                "items": {
                                                                    "type": "string"
                                                                },
                                                                "maxItems": 16,
                                                                "type": "array",
                                                                "nullable": true
                                                            },
                                                            "set": {
                                                                "items": {
                                                                    "properties": {
                                                                        "name": {
                                                                            "maxLength": 256,
                                                                            "minLength": 1,
                                                                            "type": "string",
                                                                            "pattern": "^[A-Za-z0-9!#$%&'*+\\-.^_\\x60|~]+$"
                                                                        },
                                                                        "value": {
                                                                            "maxLength": 4096,
                                                                            "minLength": 1,
                                                                            "type": "string"
                                                                        }
                                                                    },
                                                                    "required": [
                                                                        "name",
                                                                        "value"
                                                                    ],
                                                                    "type": "object"
                                                                },
                                                                "maxItems": 16,
                                                                "type": "array",
                                                                "nullable": true
                                                            }
                                                        },
                                                        "type": "object",
                                                        "nullable": true
                                                    },
                                                    "requestRedirect": {
                                                        "properties": {
                                                            "hostname": {
                                                                "maxLength": 253,
                                                                "minLength": 1,
                                                                "type": "string",
                                                                "pattern": "^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$",
                                                                "nullable": true
                                                            },
                                                            "path": {
                                                                "properties": {
                                                                    "replaceFullPath": {
                                                                        "maxLength": 1024,
                                                                        "type": "string",
                                                                        "nullable": true
                                                                    },
                                                                    "replacePrefixMatch": {
                                                                        "maxLength": 1024,
                                                                        "type": "string",
                                                                        "nullable": true
                                                                    },
                                                                    "type": {
                                                                        "enum": [
                                                                            "ReplaceFullPath",
                                                                            "ReplacePrefixMatch"
                                                                        ],
                                                                        "type": "string"
                                                                    }
                                                                },
                                                                "required": [
                                                                    "type"
                                                                ],
                                                                "type": "object",
                                                                "nullable": true
                                                            },
                                                            "port": {
                                                                "format": "int32",
                                                                "type": "integer",
                                                                "minimum": 1,
                                                                "maximum": 65535,
                                                                "nullable": true
                                                            },
                                                            "scheme": {
                                                                "enum": [
                                                                    "http",
                                                                    "https"
                                                                ],
                                                                "type": "string",
                                                                "nullable": true
                                                            },
                                                            "statusCode": {
                                                                "default": 302,
                                                                "enum": [
                                                                    301,
                                                                    302
                                                                ],
                                                                "type": "integer",
                                                                "nullable": true
                                                            }
                                                        },
                                                        "type": "object",
                                                        "nullable": true
                                                    },
                                                    "responseHeaderModifier": {
                                                        "properties": {
                                                            "add": {
                                                                "items": {
                                                                    "properties": {
                                                                        "name": {
                                                                            "maxLength": 256,
                                                                            "minLength": 1,
                                                                            "type": "string",
                                                                            "pattern": "^[A-Za-z0-9!#$%&'*+\\-.^_\\x60|~]+$"
                                                                        },
                                                                        "value": {
                                                                            "maxLength": 4096,
                                                                            "minLength": 1,
                                                                            "type": "string"
                                                                        }
                                                                    },
                                                                    "required": [
                                                                        "name",
                                                                        "value"
                                                                    ],
                                                                    "type": "object"
                                                                },
                                                                "maxItems": 16,
                                                                "type": "array",
                                                                "nullable": true
                                                            },
                                                            "remove": {
                                                                "items": {
                                                                    "type": "string"
                                                                },
                                                                "maxItems": 16,
                                                                "type": "array",
                                                                "nullable": true
                                                            },
                                                            "set": {
                                                                "items": {
                                                                    "properties": {
                                                                        "name": {
                                                                            "maxLength": 256,
                                                                            "minLength": 1,
                                                                            "type": "string",
                                                                            "pattern": "^[A-Za-z0-9!#$%&'*+\\-.^_\\x60|~]+$"
                                                                        },
                                                                        "value": {
                                                                            "maxLength": 4096,
                                                                            "minLength": 1,
                                                                            "type": "string"
                                                                        }
                                                                    },
                                                                    "required": [
                                                                        "name",
                                                                        "value"
                                                                    ],
                                                                    "type": "object"
                                                                },
                                                                "maxItems": 16,
                                                                "type": "array",
                                                                "nullable": true
                                                            }
                                                        },
                                                        "type": "object",
                                                        "nullable": true
                                                    },
                                                    "type": {
                                                        "enum": [
                                                            "RequestHeaderModifier",
                                                            "ResponseHeaderModifier",
                                                            "RequestRedirect"
                                                        ],
                                                        "type": "string"
                                                    }
                                                },
                                                "required": [
                                                    "type"
                                                ],
                                                "type": "object"
                                            },
                                            "maxItems": 16,
                                            "type": "array",
                                            "nullable": true
                                        }
                                    },
                                    "required": [
                                        "name"
                                    ],
                                    "type": "object"
                                },
                                "maxItems": 16,
                                "type": "array",
                                "nullable": true
                            },
                            "filters": {
                                "items": {
                                    "properties": {
                                        "requestHeaderModifier": {
                                            "properties": {
                                                "add": {
                                                    "items": {
                                                        "properties": {
                                                            "name": {
                                                                "maxLength": 256,
                                                                "minLength": 1,
                                                                "type": "string",
                                                                "pattern": "^[A-Za-z0-9!#$%&'*+\\-.^_\\x60|~]+$"
                                                            },
                                                            "value": {
                                                                "maxLength": 4096,
                                                                "minLength": 1,
                                                                "type": "string"
                                                            }
                                                        },
                                                        "required": [
                                                            "name",
                                                            "value"
                                                        ],
                                                        "type": "object"
                                                    },
                                                    "maxItems": 16,
                                                    "type": "array",
                                                    "nullable": true
                                                },
                                                "remove": {
                                                    "items": {
                                                        "type": "string"
                                                    },
                                                    "maxItems": 16,
                                                    "type": "array",
                                                    "nullable": true
                                                },
                                                "set": {
                                                    "items": {
                                                        "properties": {
                                                            "name": {
                                                                "maxLength": 256,
                                                                "minLength": 1,
                                                                "type": "string",
                                                                "pattern": "^[A-Za-z0-9!#$%&'*+\\-.^_\\x60|~]+$"
                                                            },
                                                            "value": {
                                                                "maxLength": 4096,
                                                                "minLength": 1,
                                                                "type": "string"
                                                            }
                                                        },
                                                        "required": [
                                                            "name",
                                                            "value"
                                                        ],
                                                        "type": "object"
                                                    },
                                                    "maxItems": 16,
                                                    "type": "array",
                                                    "nullable": true
                                                }
                                            },
                                            "type": "object",
                                            "nullable": true
                                        },
                                        "requestRedirect": {
                                            "properties": {
                                                "hostname": {
                                                    "maxLength": 253,
                                                    "minLength": 1,
                                                    "type": "string",
                                                    "pattern": "^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$",
                                                    "nullable": true
                                                },
                                                "path": {
                                                    "properties": {
                                                        "replaceFullPath": {
                                                            "maxLength": 1024,
                                                            "type": "string",
                                                            "nullable": true
                                                        },
                                                        "replacePrefixMatch": {
                                                            "maxLength": 1024,
                                                            "type": "string",
                                                            "nullable": true
                                                        },
                                                        "type": {
                                                            "enum": [
                                                                "ReplaceFullPath",
                                                                "ReplacePrefixMatch"
                                                            ],
                                                            "type": "string"
                                                        }
                                                    },
                                                    "required": [
                                                        "type"
                                                    ],
                                                    "type": "object",
                                                    "nullable": true
                                                },
                                                "port": {
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "minimum": 1,
                                                    "maximum": 65535,
                                                    "nullable": true
                                                },
                                                "scheme": {
                                                    "enum": [
                                                        "http",
                                                        "https"
                                                    ],
                                                    "type": "string",
                                                    "nullable": true
                                                },
                                                "statusCode": {
                                                    "default": 302,
                                                    "enum": [
                                                        301,
                                                        302
                                                    ],
                                                    "type": "integer",
                                                    "nullable": true
                                                }
                                            },
                                            "type": "object",
                                            "nullable": true
                                        },
                                        "type": {
                                            "enum": [
                                                "RequestHeaderModifier",
                                                "RequestRedirect"
                                            ],
                                            "type": "string"
                                        }
                                    },
                                    "required": [
                                        "type"
                                    ],
                                    "type": "object"
                                },
                                "maxItems": 16,
                                "type": "array",
                                "nullable": true
                            },
                            "matches": {
                                "default": [
                                    {
                                        "path": {
                                            "type": "PathPrefix",
                                            "value": "/"
                                        }
                                    }
                                ],
                                "items": {
                                    "properties": {
                                        "headers": {
                                            "items": {
                                                "properties": {
                                                    "name": {
                                                        "maxLength": 256,
                                                        "minLength": 1,
                                                        "type": "string",
                                                        "pattern": "^[A-Za-z0-9!#$%&'*+\\-.^_\\x60|~]+$"
                                                    },
                                                    "type": {
                                                        "default": "Exact",
                                                        "enum": [
                                                            "Exact",
                                                            "RegularExpression"
                                                        ],
                                                        "type": "string",
                                                        "nullable": true
                                                    },
                                                    "value": {
                                                        "maxLength": 4096,
                                                        "minLength": 1,
                                                        "type": "string"
                                                    }
                                                },
                                                "required": [
                                                    "name",
                                                    "value"
                                                ],
                                                "type": "object"
                                            },
                                            "maxItems": 16,
                                            "type": "array",
                                            "nullable": true
                                        },
                                        "method": {
                                            "enum": [
                                                "GET",
                                                "HEAD",
                                                "POST",
                                                "PUT",
                                                "DELETE",
                                                "CONNECT",
                                                "OPTIONS",
                                                "TRACE",
                                                "PATCH"
                                            ],
                                            "type": "string",
                                            "nullable": true
                                        },
                                        "path": {
                                            "default": {
                                                "type": "PathPrefix",
                                                "value": "/"
                                            },
                                            "properties": {
                                                "type": {
                                                    "default": "PathPrefix",
                                                    "enum": [
                                                        "Exact",
                                                        "PathPrefix",
                                                        "RegularExpression"
                                                    ],
                                                    "type": "string",
                                                    "nullable": true
                                                },
                                                "value": {
                                                    "default": "/",
                                                    "maxLength": 1024,
                                                    "type": "string",
                                                    "nullable": true
                                                }
                                            },
                                            "type": "object",
                                            "nullable": true
                                        },
                                        "queryParams": {
                                            "items": {
                                                "properties": {
                                                    "name": {
                                                        "maxLength": 256,
                                                        "minLength": 1,
                                                        "type": "string"
                                                    },
                                                    "type": {
                                                        "default": "Exact",
                                                        "enum": [
                                                            "Exact",
                                                            "RegularExpression"
                                                        ],
                                                        "type": "string",
                                                        "nullable": true
                                                    },
                                                    "value": {
                                                        "maxLength": 1024,
                                                        "minLength": 1,
                                                        "type": "string"
                                                    }
                                                },
                                                "required": [
                                                    "name",
                                                    "value"
                                                ],
                                                "type": "object"
                                            },
                                            "maxItems": 16,
                                            "type": "array",
                                            "nullable": true
                                        }
                                    },
                                    "type": "object"
                                },
                                "maxItems": 8,
                                "type": "array",
                                "nullable": true
                            },
                            "timeouts": {
                                "properties": {
                                    "backendRequest": {
                                        "format": "duration",
                                        "type": "string",
                                        "nullable": true
                                    },
                                    "request": {
                                        "format": "duration",
                                        "type": "string",
                                        "nullable": true
                                    }
                                },
                                "type": "object",
                                "nullable": true
                            }
                        },
                        "type": "object"
                    },
                    "maxItems": 16,
                    "type": "array",
                    "nullable": true
                }
            },
            "type": "object"
        },
        "status": {
            "properties": {
                "parents": {
                    "items": {
                        "properties": {
                            "conditions": {
                                "items": {
                                    "properties": {
                                        "lastTransitionTime": {
                                            "format": "date-time",
                                            "type": "string"
                                        },
                                        "message": {
                                            "maxLength": 32768,
                                            "type": "string"
                                        },
                                        "observedGeneration": {
                                            "format": "int64",
                                            "type": "integer",
                                            "minimum": 0,
                                            "nullable": true
                                        },
                                        "reason": {
                                            "maxLength": 1024,
                                            "minLength": 1,
                                            "type": "string",
                                            "pattern": "^[A-Za-z]([A-Za-z0-9_,:]*[A-Za-z0-9_])?$"
                                        },
                                        "status": {
                                            "enum": [
                                                "True",
                                                "False",
                                                "Unknown"
                                            ],
                                            "type": "string"
                                        },
                                        "type": {
                                            "maxLength": 316,
                                            "type": "string",
                                            "pattern": "^([a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*\\/)?(([A-Za-z0-9][-A-Za-z0-9_.]*)?[A-Za-z0-9])$"
                                        }
                                    },
                                    "required": [
                                        "lastTransitionTime",
                                        "message",
                                        "reason",
                                        "status",
                                        "type"
                                    ],
                                    "type": "object"
                                },
                                "maxItems": 8,
                                "minItems": 1,
                                "type": "array",
                                "nullable": true
                            },
                            "controllerName": {
                                "maxLength": 253,
                                "minLength": 1,
                                "type": "string",
                                "pattern": "^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*\\/[A-Za-z0-9\\/\\-._~%!$&'()*+,;=:]+$"
                            },
                            "parentRef": {
                                "properties": {
                                    "group": {
                                        "default": "policy.linkerd.io",
                                        "maxLength": 253,
                                        "type": "string",
                                        "pattern": "^$|^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$",
                                        "nullable": true
                                    },
                                    "kind": {
                                        "default": "Gateway",
                                        "maxLength": 63,
                                        "minLength": 1,
                                        "type": "string",
                                        "pattern": "^[a-zA-Z]([-a-zA-Z0-9]*[a-zA-Z0-9])?$",
                                        "nullable": true
                                    },
                                    "name": {
                                        "maxLength": 253,
                                        "minLength": 1,
                                        "type": "string"
                                    },
                                    "namespace": {
                                        "maxLength": 63,
                                        "minLength": 1,
                                        "type": "string",
                                        "pattern": "^[a-z0-9]([-a-z0-9]*[a-z0-9])?$",
                                        "nullable": true
                                    },
                                    "sectionName": {
                                        "maxLength": 253,
                                        "minLength": 1,
                                        "type": "string",
                                        "pattern": "^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$",
                                        "nullable": true
                                    }
                                },
                                "required": [
                                    "name"
                                ],
                                "type": "object"
                            }
                        },
                        "required": [
                            "controllerName",
                            "parentRef"
                        ],
                        "type": "object"
                    },
                    "maxItems": 32,
                    "type": "array"
                }
            },
            "required": [
                "parents"
            ],
            "type": "object",
            "nullable": true
        }
    },
    "required": [
        "spec",
        "apiVersion",
        "kind"
    ]
};
/**
 * HTTPRoute provides a way to route HTTP requests. This includes the capability to match requests by hostname, path, header, or query param. Filters can be used to specify additional processing steps. Backends specify where matching requests should be routed.
 */
export class HTTPRoute extends Model {
    constructor(data) {
        super({
            apiVersion: HTTPRoute.apiVersion,
            kind: HTTPRoute.kind,
            ...data
        });
    }
}
HTTPRoute.apiVersion = "policy.linkerd.io/v1beta3";
HTTPRoute.kind = "HTTPRoute";
HTTPRoute.is = createTypeMetaGuard(HTTPRoute);
setSchema(HTTPRoute, schemaId, () => {
    addSchema();
    register(schemaId, schema);
});
